<?php

namespace Drupal\opencase\Plugin\Block;

use Drupal\Core\Block\BlockBase;

/**
 * Provides a Block with some help text about actor type fields
 *
 * @Block(
 *   id = "add_activity",
 *   admin_label = @Translation("Add Activity"),
 *   category = @Translation("Opencase"),
 * )
 */
class AddActivity extends BlockBase {

    /**
     * {@inheritdoc}
     */
    public function build():array {
        $actor = \Drupal::routeMatch()->getParameter('oc_actor');
        $target_id = $actor->id();
        $actorType = $actor->bundle();
        $markup = "<ul>";
        $activity_types = $this->getActivityTypesToDisplay($actorType);
        foreach($activity_types as $id => $info) {
            $label = $info['label'];
            $markup .= "<li><a href='/opencase/oc_activity/add/$id?target_id=$target_id&destination=/opencase/oc_actor/$target_id'>$label</a></li>";
        }
        $markup .= "</ul>";
        return array('#markup' => $markup);
    }

    public function getCacheMaxAge():int {
        return 0;
    }

    private function getActivityTypesToDisplay(string $actorType): array {
        // Client modules will provide a list of what activity types (bundles) are relevant for each actor type.
        // Check if they are implemented, and if so display them.
        $implemented_activity_types = \Drupal::service('entity_type.bundle.info')->getBundleInfo('oc_activity');
        $relevant_activity_type_ids = \Drupal::moduleHandler()->invokeAll('relevant_activity_type_ids', [$actorType]);
        $activity_types_to_display = [];
        foreach ($relevant_activity_type_ids as $type_id) {
            if (array_key_exists($type_id, $implemented_activity_types)) {
                $activity_types_to_display[$type_id] = $implemented_activity_types[$type_id];
            }
        }
        return $activity_types_to_display;
    }
}
